# 文献启明星（LightStar）- 科研调研智能体系统

## 项目简介

**文献启明星**是一款面向科研初学者的 AI 智能体系统，致力于帮助用户从模糊的研究意图出发，自动完成科研调研的核心流程，包括：主题拆解、文献检索、文献聚类、结构总结、代表文献推荐与调研报告生成。

用户仅需输入一句话，即可获得一份结构化的初步调研成果，用于选题、开题、综述写作或项目申报。本项目采用前后端分离架构，支持多端适配（Web、移动、桌面），为不同场景下的科研人员提供便捷服务。

## 技术架构

### 后端 (Backend)
- **框架**: FastAPI
- **语言**: Python 3.9+
- **核心依赖**:
  - arxiv API (文献检索)
  - sentence-transformers (文本向量化)
  - scikit-learn (聚类分析)

### 前端 (Frontend)
- **框架**: Next.js 15
- **UI构建**: Tailwind CSS 3
- **动画效果**: Framer Motion
- **特色功能**:
  - 响应式设计，适配不同设备
  - 多主题切换系统 (深邃宇宙、高级深海、现代科技、精致夜光)
  - 玻璃态UI设计 (Glassmorphism)

## 项目结构

```bash
lightstar/
├── backend/                    # FastAPI后端服务
│   ├── main.py                 # 主入口
│   ├── config.py               # 配置文件
│   ├── api/                    # API路由
│   ├── core/                   # 核心业务逻辑
│   │   ├── research.py         # 研究流程
│   │   ├── clustering.py       # 聚类算法
│   │   └── report.py           # 报告生成
│   └── utils/                  # 工具函数
│
└── lightstar-web/              # Next.js前端应用
    ├── src/
    │   ├── app/                # 页面
    │   ├── components/         # UI组件
    │   │   ├── ui/             # 基础UI组件
    │   │   └── forms/          # 表单组件
    │   └── lib/                # 工具函数
    └── public/                 # 静态资源
```

## 使用说明

### 后端服务启动

```bash
cd backend
pip install -r requirements.txt
python main.py
```

后端服务将在 http://localhost:8000 启动

### 前端应用启动

```bash
cd lightstar-web
npm install
npm run dev
```

前端应用将在 http://localhost:3000 启动

## 功能特点

- 智能研究主题解析
- 自动文献检索与分析
- 文献聚类与可视化
- 研究报告自动生成
- 多主题UI，提供舒适的视觉体验
- 响应式设计，支持各类设备

---

## 二、目标用户

- 初入科研的硕士/博士研究生
- 缺乏调研经验的年轻教师或科研助理
- 对某一新领域感兴趣的项目开发人员
- 需要在多种设备上进行科研调研的研究人员

---

## 三、核心价值

| 用户痛点 | 文献启明星的解决方案 |
|----------|----------------------|
| 不会选题、不知从哪开始 | AI 拆解主题，提炼研究方向 |
| 不会查文献，效率低 | 自动调用开放数据库进行检索 |
| 无法判断文献质量 | 提供引用数、摘要、推荐标记 |
| 看完文献却写不出综述 | 聚类归纳 + 自动报告生成 |
| 时间紧、任务重、无从下手 | 一站式完成调研闭环 |
| 需要随时随地进行研究 | 多端适配，支持Web/移动/桌面 |

---

## 四、功能流程图

```text
用户输入研究意图
         ↓
AI 拆解关键词与子主题
         ↓
调用文献 API 自动检索（arXiv / Semantic Scholar）
         ↓
聚类文献主题，归纳关键词与研究路线
         ↓
推荐经典/综述文献（摘要 + 链接）
         ↓
输出结构化调研报告草稿（可导出）
```

---

## 五、核心功能模块

| 模块 | 功能描述 |
|------|----------|
| 主题解析模块 | 拆分研究意图，生成关键词树与子问题列表 |
| 文献检索模块 | 接入开放 API，按主题获取高质量文献元数据 |
| 文献聚类模块 | 使用向量聚类，分析研究方向脉络与热点 |
| 推荐与标注模块 | 推荐高引用文献与综述，添加标签与摘要 |
| 报告生成模块 | 调用大模型生成调研报告初稿（1000~1500字） |
| 可视化模块 | 关键词云、主题聚类图、研究路线图等 |

---

## 六、技术架构（前后端分离多端适配）

### 后端架构
- **FastAPI**：高性能API框架，提供核心功能接口
- **Python 3.9+**：后端开发语言
- **Pydantic**：数据验证和序列化
- **SQLAlchemy**：数据持久化（可选）
- **文献API集成**：arXiv/Semantic Scholar/Crossref
- **大模型调用**：DeepSeek/其他大语言模型
- **文本向量化**：sentence-transformers + 向量索引

### 前端架构
- **Web端**：React/Next.js 构建SPA应用
- **移动端**：React Native/Flutter 实现跨平台移动应用
- **桌面端**：Electron 打包桌面应用
- **统一状态管理**：确保各端数据一致性
- **离线功能支持**：本地缓存和同步机制

---

## 七、项目结构
lightstar/
├── backend/ # 后端API服务
│ ├── main.py # FastAPI入口
│ ├── config.py # 配置文件
│ ├── api/ # API路由
│ ├── core/ # 核心业务逻辑
│ └── utils/ # 工具函数
│
├── frontend/ # 前端应用
│ ├── web/ # Web应用
│ ├── mobile/ # 移动应用
│ └── desktop/ # 桌面应用
│
└── README.md # 项目说明文档

---

## 八、用户交互示例

**输入：**
我想研究碳中和背景下的氢能运输方式

**输出：**
- 拆解主题为：碳中和 / 氢能 / 储运 / 能效
- 聚类出三类主流方向：液氢技术、固态储运、长距离管网
- 推荐 6 篇代表性论文（含摘要与链接）
- 输出一篇可编辑的调研报告草稿

---

## 九、项目落地优势

- **多端适配**：适用于实验室、课堂、移动场景等多种使用环境
- **独立开发可行**：模块化设计，便于分阶段实现
- **前后端分离**：便于团队协作和功能扩展
- **API驱动设计**：为未来的第三方集成提供基础
- **无复杂训练需求**：依赖现有开源模型和API，降低部署门槛
- **实际需求驱动**：直接解决科研人员的真实痛点

---

## 十、后续可拓展方向

- **账户系统**：跨设备同步研究历史和成果
- **协作功能**：支持多人协同进行文献调研
- **智能推荐**：基于用户历史研究兴趣推荐相关主题
- **知识图谱**：构建研究领域知识网络
- **插件生态**：与Zotero、Notion等工具集成
- **多语言支持**：扩展至更多科研语言环境
- **离线模式**：支持无网络环境下基本功能使用

---

## 十一、开发路线图

### 第一阶段：后端核心功能
- 实现基础API架构
- 完成关键词提取模块
- 集成文献检索API
- 实现基础聚类算法
- 开发报告生成功能

### 第二阶段：Web端开发
- 构建Web界面
- 实现交互功能
- 完成可视化组件
- 用户数据管理

### 第三阶段：移动与桌面适配
- 开发移动应用
- 构建桌面客户端
- 实现多端数据同步
- 支持离线功能

---

## 十二、技术依赖

| 依赖类型 | 主要技术 |
|---------|---------|
| 后端框架 | FastAPI, SQLAlchemy |
| 前端技术 | React/Next.js, React Native/Flutter, Electron |
| AI模型 | DeepSeek, Sentence-Transformers |
| 外部API | arXiv, Semantic Scholar, Crossref |
| 数据处理 | Pandas, FAISS, Scikit-learn |
| 可视化 | Plotly, D3.js |