import { GlassCard } from "@/components/ui/glass-card";
import { ResearchForm } from "@/components/forms/research-form";
import { ThemeSelector } from "@/components/theme-selector";

export default function Home() {
  return (
    <main className="relative flex min-h-screen flex-col items-center justify-center p-4 sm:p-8 bg-gradient-to-br from-[var(--theme-bg-from)] via-[var(--theme-bg-via)] to-[var(--theme-bg-to)]">
      {/* 主题选择器 */}
      <ThemeSelector />
      
      {/* 背景装饰 */}
      <div className="absolute inset-0 overflow-hidden pointer-events-none">
        <div className="stars absolute inset-0 z-0"></div>
        <div className="absolute top-1/4 left-1/3 w-[30rem] h-[30rem] bg-[var(--theme-accent)] rounded-full mix-blend-screen filter blur-[150px] opacity-20 animate-blob"></div>
        <div className="absolute top-1/3 right-1/4 w-[25rem] h-[25rem] bg-[var(--theme-highlight)] rounded-full mix-blend-screen filter blur-[120px] opacity-20 animate-blob animation-delay-2000"></div>
        <div className="absolute bottom-1/4 right-1/3 w-[20rem] h-[20rem] bg-white rounded-full mix-blend-screen filter blur-[100px] opacity-10 animate-blob animation-delay-4000"></div>
      </div>
      
      <div className="container max-w-xl mx-auto z-10">
        <div className="text-center mb-8">
          <h1 className="text-5xl md:text-6xl font-bold text-center text-transparent bg-clip-text bg-gradient-to-r from-white to-white/70 mb-3 drop-shadow-lg animate-pulse">
            文献启明星
          </h1>
          <p className="text-xl text-center text-white/80 mb-2">
            科研调研智能体系统
          </p>
          <div className="w-16 h-1 mx-auto bg-gradient-to-r from-[var(--theme-accent)] to-[var(--theme-highlight)] rounded-full"></div>
        </div>
        
        <GlassCard className="w-full">
          <ResearchForm />
        </GlassCard>
        
        <p className="text-white/50 text-center text-xs mt-8">
          基于人工智能的论文检索与分析系统
        </p>
      </div>
    </main>
  );
}
