"use client";

import { cn } from "@/lib/utils";
import { motion } from "framer-motion";
import React from "react";

interface GlassCardProps extends React.HTMLAttributes<HTMLDivElement> {
  children: React.ReactNode;
  className?: string;
  hoverEffect?: boolean;
}

export function GlassCard({
  children,
  className,
  hoverEffect = true,
  ...props
}: GlassCardProps) {
  return (
    <motion.div
      className={cn(
        "relative rounded-2xl backdrop-blur-xl bg-white/15 dark:bg-slate-900/20 p-8 shadow-[0_8px_30px_rgba(0,0,0,0.12)] border border-white/10 dark:border-slate-700/10",
        hoverEffect && "hover:bg-white/20 dark:hover:bg-slate-800/20 transition-all duration-300",
        className
      )}
      initial={{ opacity: 0, y: 20 }}
      animate={{ opacity: 1, y: 0 }}
      transition={{ duration: 0.4, ease: "easeOut" }}
      whileHover={
        hoverEffect
          ? { y: -8, boxShadow: "0 20px 40px rgba(0,0,0,0.2)" }
          : {}
      }
      {...props}
    >
      {/* 装饰元素 */}
      <div className="absolute top-0 right-0 -mt-4 -mr-4 h-10 w-10 rounded-full bg-gradient-to-br from-[var(--theme-highlight)] to-[var(--theme-accent)] opacity-70 blur-xl"></div>
      <div className="absolute bottom-0 left-0 -mb-4 -ml-4 h-8 w-8 rounded-full bg-gradient-to-tr from-[var(--theme-accent)] to-[var(--theme-highlight)] opacity-60 blur-xl"></div>
      {children}
    </motion.div>
  );
}
